AA.df.check: Contingency Table Check

View source: R/A_support_functions.R

AA.df.checkR Documentation

Contingency Table Check

Description

Checks amino acid contingency table data frame to ensure required variation exists.

Usage

AA.df.check(x, Strict.Bin)

Arguments

x

contingency table.

Strict.Bin

Logical specify if strict rare cell binning should be used in ChiSq test.

Note

This function is for internal BIGDAWG use only.


BIGDAWG documentation built on April 30, 2026, 9:08 a.m.