AA.df.cs: Contingency Table Amino Acid ChiSq Testing

View source: R/A_support_functions.R

AA.df.csR Documentation

Contingency Table Amino Acid ChiSq Testing

Description

Runs ChiSq test on amino acid contingency table data frames.

Usage

AA.df.cs(x, Strict.Bin)

Arguments

x

contingency table.

Strict.Bin

Logical specify if strict rare cell binning should be used in ChiSq test.

Note

This function is for internal BIGDAWG use only.


BIGDAWG documentation built on April 30, 2026, 9:08 a.m.