| Err.Log | R Documentation |
Displays error codes attributable to data formatting and Locus/Allele naming. Writes to log file.
Err.Log(Output, x, y = NULL, z = NULL)
Output |
Logical indicating if Error logging should be written to a file. |
x |
Log Code. |
y |
Misc information relevant to error. |
z |
Misc information relevant to error. |
This function is for internal BIGDAWG use only.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.