| ExonPtnList | R Documentation |
Alignment object for use in the amino acid analysis.
ExonPtnList
A list where each element is an alignment dataframe for a single locus.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.