View source: R/update_wrapper.R
| UpdateRelease | R Documentation |
This updates the protein aligment used in checking HLA loci and alleles as well as in the amino acid analysis.
UpdateRelease(Force = F, Restore = F, Output = F)
Force |
Logical specifiying if update should be forced. |
Restore |
Logical specifying if the original alignment file be restored. |
Output |
Logical indicating if error reporting should be written to file. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.