View source: R/A_support_functions.R
| AA.df.cs | R Documentation |
Runs ChiSq test on amino acid contingency table data frames.
AA.df.cs(x, Strict.Bin)
x |
contingency table. |
Strict.Bin |
Logical specify if strict rare cell binning should be used in ChiSq test. |
This function is for internal BIGDAWG use only.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.