FixAlleleName: Allele Name Format Fix
Description
Separate locus and allele names if data is formatted as Loci*Allele
Usage
FixAlleleName(Output, Tab)
Arguments
Output
Logical indicating if Error logging should be written to a file.
Tab
All columns of HLA genotyping data.